==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/admin/inc/tree/messagequeue.php <==
<?
    require_once("inc/formvariables.php");
	require_once("inc/statistics.php");
	require_once("inc/mailbox.php");
	require_once("inc/editfile.php");
	
	$object = $_REQUEST['object'];
	$type = $_REQUEST['type'];
	$s_type = $_REQUEST['s_type'];
	$object = $_REQUEST['object'];
	
	
	function getmessages($object,$type,$s_type,&$skindata,$u_spamfolder = false)
	{
		$stat = createobject("statistics");

		if ($type=='server') {
				$object = '';
				$skindata['server'] = 1;
					 
					 $fileid = 'server_in';
					 @$filename = processmailboxaction($object,$fileid);
					 @$itemsin = processmailbox($object,$fileid);
					 
					 $fileid = 'server_out';
					 @$filename = processmailboxaction($object,$fileid);
					 @$itemsout = processmailbox($object,$fileid);
					 
					 $fileid = 'server_outretry';
					 @$filename = processmailboxaction($object,$fileid);
					 @$itemsretry = processmailbox($object,$fileid);
			switch ($s_type)
				{		 
				case 'serverin':
					$items = $itemsin;
					$skindata['sin'] = 1;
				break;
				case 'serverout':
					$items = array_merge($itemsretry,$itemsout);
					$skindata['sout'] = 1;			 
				break;
				case 'all':
					$items = array_merge($itemsin,$itemsout,$itemsretry);
					$skindata['sall'] = 1;
				break;
			}
			$skindata['items']['num'] = $items;
		}else
		{
			$skindata['mbox'] = 1;
			$fileid = 'mailbox_view';
			if (!isset($object)) $object = $_SESSION["EMAIL"];
			@$filename = processmailboxaction($object,$fileid);
			@$skindata['items']['num'] = processmailbox($object,$fileid,$u_spamfolder);
		}
		$skindata['object'] = $object;
		$skindata['fileid'] = $fileid;
	}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/admin/inc/tree/messagequeue.php <==
<?
    require_once("inc/formvariables.php");
	require_once("inc/statistics.php");
	require_once("inc/mailbox.php");
	require_once("inc/editfile.php");
	
	$object = $_REQUEST['object'];
	$type = $_REQUEST['type'];
	$s_type = $_REQUEST['s_type'];
	
	
	function getmessages($object,$type,$s_type,&$skindata,$u_spamfolder = 0)
	{
		$stat = createobject("statistics");

		if ($type=='server') {
				$object = '';
				$skindata['server'] = 1;
					 
					 $fileid = 'server_in';
					 processmailboxaction($object,$fileid);
					 @$itemsin = processmailbox($object,$fileid);
					 
					 $fileid = 'server_out';
					 processmailboxaction($object,$fileid);
					 @$itemsout = processmailbox($object,$fileid);
					 
					 $fileid = 'server_outretry';
					 processmailboxaction($object,$fileid);
					 @$itemsretry = processmailbox($object,$fileid);
			switch ($s_type)
				{		 
				case 'serverin':
					$items = $itemsin;
					$skindata['sin'] = 1;
				break;
				case 'serverout':
					$items = array_merge($itemsretry,$itemsout);
					$skindata['sout'] = 1;			 
				break;
				case 'all':
					$items = array_merge($itemsin,$itemsout,$itemsretry);
					$skindata['sall'] = 1;
				break;
			}
			$skindata['items']['num'] = $items;
		}else
		{
		  

			$skindata['mbox'] = 1; 
			$fileid = (!$u_spamfolder)?'mailbox_view':'spambox_view';
			if (!isset($object)) $object = $_SESSION["EMAIL"];
			processmailboxaction($object,$fileid);
			@$skindata['items']['num'] = processmailbox($object,$fileid,$u_spamfolder);
		}
		$skindata['object'] = $object;
		$skindata['fileid'] = $fileid;
	}
?>
